CoreConstants class

Constructors

CoreConstants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

X_CORE_SDK_VERSION → const String
X_SDK_TYPE → const String
X_SDK_VERSION → const String
X_SIGN_SDK_VERSION → const String