GetQuoteParams class sealed

Available extensions
Annotations
  • @freezed

Constructors

GetQuoteParams({required ExchangeAsset sourceToken, required ExchangeAsset toToken, required String recipient, required String amount, String? address})
const
factory
GetQuoteParams.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
no setterinherited
amount String
no setterinherited
copyWith → $GetQuoteParamsCopyWith<GetQuoteParams>
Create a copy of GetQuoteParams with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
recipient String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceToken ExchangeAsset
no setterinherited
toToken ExchangeAsset
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GetQuoteParams value)) → TResult

Available on GetQuoteParams, provided by the GetQuoteParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GetQuoteParams value)?) → TResult?

Available on GetQuoteParams, provided by the GetQuoteParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GetQuoteParams value)?, {required TResult orElse()}) → TResult

Available on GetQuoteParams, provided by the GetQuoteParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ExchangeAsset sourceToken, ExchangeAsset toToken, String recipient, String amount, String? address)?, {required TResult orElse()}) → TResult

Available on GetQuoteParams, provided by the GetQuoteParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetQuoteParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ExchangeAsset sourceToken, ExchangeAsset toToken, String recipient, String amount, String? address)) → TResult

Available on GetQuoteParams, provided by the GetQuoteParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ExchangeAsset sourceToken, ExchangeAsset toToken, String recipient, String amount, String? address)?) → TResult?

Available on GetQuoteParams, provided by the GetQuoteParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited