SessionAuthResponse class

Inheritance

Constructors

SessionAuthResponse({required int id, required String topic, List<Cacao>? auths, SessionData? session, ReownSignError? error, JsonRpcError? jsonRpcError})

Properties

auths → List<Cacao>?
final
error → ReownSignError?
final
eventName ↔ String?
The name of associated Event. Default value is null. Typically set by external code.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
jsonRpcError → JsonRpcError?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → SessionData?
final
topic → String
final
whenOccurred ↔ DateTime?
The date/time when the event is broadcast. Until broadcast, the value is null.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited