ProgramException class

Program Exception

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

ProgramException(String message, {int? code})
Creates an exception for a program error.
const
ProgramException.fromJson(Map<String, dynamic> json)
Creates an instance of this class from the constructor parameters defined in the json object.
factory

Properties

code → int?
The error type.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
A short description of the error.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialises this class into a JSON object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited